@@ -1,4 +1,21 @@
 <?php
+/* 	OpenDb - Open Media Lending Database
+	Copyright (C) 2001,2002 by Jason Pell
+
+	This program is free software; you can redistribute it and/or
+	modify it under the terms of the GNU General Public License
+	as published by the Free Software Foundation; either version 2
+	of the License, or (at your option) any later version.
+
+	This program is distributed in the hope that it will be useful,
+	but WITHOUT ANY WARRANTY; without even the implied warranty of
+	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+	GNU General Public License for more details.
+
+	You should have received a copy of the GNU General Public License
+	along with this program; if not, write to the Free Software
+	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+*/
 
 //
 // Administrator Config file
@@ -12,8 +29,8 @@ $_CORE_ATTRIBUTE_TYPES = array(
 		'ALT_TITLE','ACTORS','DIRECTOR','RUN_TIME','AUDIO_LANG','SUBTITLES','AGE_RATING',
 		'MOVIEGENRE','IMAGEURL','DVD_EXTRAS','DVD_REGION','RATIO','VID_FORMAT','VHS_TYPE',
 		'VIDQUALITY','COMMENTS','MOVIE_PLOT','YEAR','ARTIST','CDTRACK','CDTIME','MUSICGENRE',
-		'DIVXVIDVER','DIVXAUDVER','DIVXQUALIT','CDDBGENRE','FREEDB_ID','IMDB_ID','TRAILER',
-		'AMAZONASIN','S_DURATION','S_ITEM_ID','S_STATUS','S_TITLE','S_RATING','S_STATCMNT'
+		'DIVXVIDVER','DIVXAUDVER','DIVXQUALIT','S_DURATION','S_ITEM_ID','S_STATUS','S_TITLE',
+		'S_RATING','S_STATCMNT','IMDBRATING'
 	);
 	
 $_FORM_HELP = array(
@@ -23,5 +40,5 @@ $_FORM_HELP = array(
 				' even if no other site plugins are specifically linked.'),
 	// Display help footer in specific item type edit form. (bottom block)
 	'siat'=>array('Entries without a <b>attribute type</b> AND <b>order no</b> specified will be ignored.')
-	)
+	);
 ?>
\ No newline at end of file
