@@ -1,5 +1,5 @@
 <?php
-/* 	OpenDb - Open Lending Database Project
+/* 	OpenDb - Open Media Lending Database
 	Copyright (C) 2001,2002 by Jason Pell
 
 	This program is free software; you can redistribute it and/or
@@ -23,11 +23,13 @@ require_once("./include/begin.inc.php");
 include_once("./include/language.php");
 include_once("./include/theme.php");
 
+include_once("./functions/database.php");
+include_once("./functions/auth.php");
+include_once("./functions/logging.php");
 include_once("./functions/email.php");
 include_once("./functions/widgets.php");
-include_once("./functions/function.php");
 include_once("./functions/user.php");
-include_once("./functions/Listing.class.inc");
+include_once("./functions/HTML_Listing.class.inc");
 
 /*
 * This script supports several different operations
@@ -95,48 +97,57 @@ include_once("./functions/Listing.class.inc");
 * @param message
 * @param $HTTP_VARS - Any variables to include as hidden variables in the form.
 */
-function show_email_form($to, $toname, $from, $fromname, $subject, $message, $HTTP_VARS)
+function show_email_form($to_userid, $to_fullname, $from_userid, $from_fullname, $subject, $message, $HTTP_VARS)
 {
 	global $LANG_VARS;
 	global $PHP_SELF;
+	global $CONFIG_VARS;
 	
+	if(strlen($to_userid)>0 && strlen($to_fullname)>0)
+		$to = replace_lang_vars(array('fullname'=>$to_fullname, 'user_id'=>$to_userid), $LANG_VARS['user_name']);
+	else if(strlen($to_fullname)>0)
+		$to = $to_fullname;
+	else if(strlen($to_userid)>0)
+		$to = $to_userid;
+	
+	// format from
+	if(strlen($from_userid)>0 && strlen($from_fullname)>0)
+		$from = replace_lang_vars(array('fullname'=>$from_fullname, 'user_id'=>$from_userid), $LANG_VARS['current_user']);
+	else if(strlen($from_fullname)>0)
+		$from = $from_fullname;
+	else if(strlen($from_userid)>0)
+		$from = $from_userid;
+		
 	// Only if we have already been in this form.
 	if($HTTP_VARS['no_message'] == 'true')
 	{
 		if(strlen($subject)==0)
 			$error[] = array('error'=>$LANG_VARS['invalid_subject']);
-		if(strlen($from)==0)
-			$error[] = array('error'=>$LANG_VARS['invalid_from_address']);
 		echo format_error_block($error);
 	}
 			
 	echo("\n<table cellspacing=1 width=60% cellpadding=2 border=0>");
-	echo("\n<form action=\"$PHP_SELF\">");
+	echo("\n<form action=\"$PHP_SELF\" method=\"POST\">");
 	
 	// Indicate that we have been in this form, and have purposely left the message textarea blank.
 	$HTTP_VARS['no_message'] = 'true';
 	
-	echo get_url_fields($HTTP_VARS, NULL, array('subject','message'));
+	echo get_url_fields($HTTP_VARS, NULL, array('subject', 'message'));
 	
-	if(strlen($toname)>0 && strlen($to)>0)
-		echo format_field($LANG_VARS['to'],NULL,"&quot;".htmlspecialchars($toname)."&quot; &lt;".$to."&gt;");
-	else if(strlen($to)>0)
-		echo format_field($LANG_VARS['to'],NULL,$to);
-	else if(strlen($toname)>0) // For special 'OpenDb Administrator' to option
-		echo format_field($LANG_VARS['to'],NULL,htmlspecialchars($toname));
+	echo format_field($LANG_VARS['to'],NULL,$to);
 	
 	// Will have supplied a value for both $from and $fromname, if coming from one of the
 	// operations where the user has to be logged in.
-	if(strlen($from)>0 && strlen($fromname)>0)
-		echo format_field($LANG_VARS['from'],NULL,"&quot;".htmlspecialchars($fromname)."&quot; &lt;".$from."&gt;");
+	if(strlen($from)>0)
+		echo format_field($LANG_VARS['from'],NULL,$from);
 	else
 	{
-		echo format_field($LANG_VARS['from']."*",
+		echo format_field($LANG_VARS['from'].($CONFIG_VARS['widgets.show_prompt_compulsory_ind']!==FALSE?_theme_image("compulsory.gif", NULL, $LANG_VARS['compulsory_field'], 'top'):""),
 						NULL,
-						"<input type=\"text\" name=\"from\" size=50 value=\"".htmlspecialchars($from)."\">");
+						"<input type=\"text\" name=\"from\" size=50 value=\"".htmlspecialchars($HTTP_VARS['from'])."\">");
 	}
 	
-	echo format_field($LANG_VARS['subject']."*",
+	echo format_field($LANG_VARS['subject'].($CONFIG_VARS['widgets.show_prompt_compulsory_ind']!==FALSE?_theme_image("compulsory.gif", NULL, $LANG_VARS['compulsory_field'], 'top'):""),
 						NULL,
 						"<input type=\"text\" name=\"subject\" size=50 value=\"".htmlspecialchars($subject)."\">");
 
@@ -148,9 +159,14 @@ function show_email_form($to, $toname, $from, $fromname, $subject, $message, $HT
                 $message, // will be encoded by get_input_field function!
 				TRUE);
 
-	echo("<td nowrap>* ".$LANG_VARS['required']."</td>");
-	echo("<td align=center><input type=submit value=\"".$LANG_VARS['send_email']."\"></td>");
-	echo("</tr>");
+	if($CONFIG_VARS['widgets.show_prompt_compulsory_ind']!==FALSE)
+	{
+		echo("\n<tr><td align=left nowrap>".
+							format_help_block(array(array('img'=>'compulsory.gif', 'text'=>$LANG_VARS['compulsory_field']))).
+						"</td><td>&nbsp;</td></tr>");
+	}
+						
+	echo("<tr><td align=center><input type=submit value=\"".$LANG_VARS['send_email']."\"></td><td>&nbsp;</td></tr>");
 	echo("\n</form>");
 	echo("</table>");
 }
@@ -193,7 +209,7 @@ function send_nonphp_email($to, $toname, $from, $fromname, $subject, $message)
 * Will not check whether $user_id_rs contains the current users user_id.  It is expected
 * that this should have already been done.
 */
-function send_email_to_userids($user_id_rs, $from, $fromname, $subject, $message)
+function send_email_to_userids($user_id_rs, $fromemail, $fromname, $subject, $message)
 {
 	global $LANG_VARS;
 	
@@ -203,7 +219,7 @@ function send_email_to_userids($user_id_rs, $from, $fromname, $subject, $message
 		$touser_r = fetch_user_r($user_id);
 		if(is_not_empty_array($touser_r))
 		{
-			$result = opendb_email($touser_r['email'], $touser_r['fullname'], $from, $fromname, $subject, $message);
+			$result = opendb_email(fetch_user_email($touser_r['user_id']), $touser_r['fullname'], $fromemail, $fromname, $subject, $message);
 			if($result===TRUE)
 				$success[] = str_replace(" ", "&nbsp;", $touser_r['fullname'])." (".$user_id.")";
 			else
@@ -245,6 +261,8 @@ function get_user_id_rs($user_type_rs=NULL)
 	return $user_id_rs;
 }
 
+/**
+*/
 function get_user_ids_tovalue($user_id_rs)
 {
 	global $HTTP_SESSION_VARS;
@@ -268,240 +286,258 @@ function get_user_ids_tovalue($user_id_rs)
 	return $to;
 }
 
-session_start();
-
-if(is_opendb_valid_session() || $HTTP_VARS['op'] == 'send_to_site_admin')
+if($CONFIG_VARS['site.enable']!==FALSE)
 {
-	echo _theme_header($LANG_VARS['send_email']);
-	echo("<h2>"._theme_image("email.gif", "")."&nbsp;".$LANG_VARS['send_email']."</h2>");
-	
-	if($HTTP_VARS['op'] != 'send_to_site_admin')
+	session_start();
+	if(is_opendb_valid_session() || $HTTP_VARS['op'] == 'send_to_site_admin')
 	{
-		$user_r = fetch_user_r($HTTP_SESSION_VARS['user_id']);
-		$fromname = strlen($user_r['fullname'])>0?$user_r['fullname']:$HTTP_SESSION_VARS['user_id'];
-		$from = $user_r['email'];
+		echo _theme_header($LANG_VARS['send_email']);
+		echo("<h2>"._theme_image("email.gif", "")."&nbsp;".$LANG_VARS['send_email']."</h2>");
 		
-		$HTTP_VARS['toname'] = trim(strip_tags($HTTP_VARS['toname']));
-	}
-	
-	// Avoid any attempts to foil required validation checks.
-	$HTTP_VARS['subject'] = trim(strip_tags($HTTP_VARS['subject']));
-	$HTTP_VARS['message'] = trim(strip_tags($HTTP_VARS['message']));
-	
-	if($CONFIG_VARS['email.use_php_mail']!==FALSE && $HTTP_VARS['op'] == 'send_to_all' && is_user_admin($HTTP_SESSION_VARS['user_id'], $HTTP_SESSION_VARS['user_type']))
-	{
-		// Default toname for bulk email.
-		if(strlen($HTTP_VARS['toname'])==0)
-			$HTTP_VARS['toname'] = replace_lang_var('user_desc', $CONFIG_VARS['site.title'], $LANG_VARS['users']);
+		if($HTTP_VARS['op'] != 'send_to_site_admin')
+		{
+			$from_user_r = fetch_user_r($HTTP_SESSION_VARS['user_id']);
+			$HTTP_VARS['toname'] = trim(strip_tags($HTTP_VARS['toname']));
+		}
 		
-		// If everything is provided, we can send email.
-		if(strlen($HTTP_VARS['subject'])>0 && (strlen($HTTP_VARS['message'])>0 || $HTTP_VARS['no_message']=='true'))
+		// Avoid any attempts to foil required validation checks.
+		$HTTP_VARS['subject'] = trim(strip_tags($HTTP_VARS['subject']));
+		$HTTP_VARS['message'] = trim(strip_tags($HTTP_VARS['message']));
+		
+		if($CONFIG_VARS['email.use_php_mail']!==FALSE && $HTTP_VARS['op'] == 'send_to_all' && is_user_admin($HTTP_SESSION_VARS['user_id'], $HTTP_SESSION_VARS['user_type']))
 		{
-			send_email_to_userids(
-					get_user_id_rs(), 
-					$from, 
-					$fromname, 
-					$HTTP_VARS['subject'], 
-					$HTTP_VARS['message']);
-		}
-		else
-		{
-			show_email_form(
-					get_user_ids_tovalue(get_user_id_rs()), 
-					$HTTP_VARS['toname'], 
-					$from, 
-					$fromname, 
-					$HTTP_VARS['subject'],
-					$HTTP_VARS['message'],
-					$HTTP_VARS);
-		}
-	}
-	else if($CONFIG_VARS['email.use_php_mail']!==FALSE && $HTTP_VARS['op'] == 'send_to_usertype' && is_usertype_valid($HTTP_VARS['usertype']) && in_array(ifempty($HTTP_VARS['usertype'],'N'), get_min_user_type_r($HTTP_SESSION_VARS['user_type'])))
-	{
-		// Default toname for bulk email.
-		if(strlen($HTTP_VARS['toname'])==0)
-			$HTTP_VARS['toname'] = replace_lang_var('user_desc', get_usertype_description($HTTP_VARS['usertype']), $LANG_VARS['users']);
+			// Default toname for bulk email.
+			if(strlen($HTTP_VARS['toname'])==0)
+			{
+				$HTTP_VARS['toname'] = replace_lang_var('user_desc', $CONFIG_VARS['site.title'], $LANG_VARS['users']);
+			}
 			
-		if(strlen($HTTP_VARS['subject'])>0 && (strlen($HTTP_VARS['message'])>0 || $HTTP_VARS['no_message']=='true'))
-		{
-			send_email_to_userids(
-					get_user_id_rs(array($HTTP_VARS['usertype'])), 
-					$from, 
-					$fromname, 
-					$HTTP_VARS['subject'], 
-					$HTTP_VARS['message']);
-		}
-		else
-		{
-			show_email_form(
-					get_user_ids_tovalue(get_user_id_rs(array($HTTP_VARS['usertype']))),
-					$HTTP_VARS['toname'], 
-					$from, 
-					$fromname, 
-					$HTTP_VARS['subject'], 
-					$HTTP_VARS['message'],
-					$HTTP_VARS);
-		}
-	}
-	else if($CONFIG_VARS['email.use_php_mail']!==FALSE && $HTTP_VARS['op'] == 'send_to_uids' && (is_not_empty_array($HTTP_VARS['user_id_rs']) || strlen(trim($HTTP_VARS['checked_user_id_rs_list']))>0))
-	{
-		// Remove $user_id's that are above the user type of the current user.
-		$filtered_user_id_rs = NULL;
-		
-		// If seeded from user_listing.php, we need to consolidate the list.
-		if(is_not_empty_array($HTTP_VARS['checked_user_id_rs']) || strlen(trim($HTTP_VARS['checked_user_id_rs_list']))>0)
-		{
-			$listingObject = new Listing();
-			$listingObject->setCheckBoxColumn('user_id_rs');
-					
-			// The checked_user_id_rs and checked_user_id_rs_list variables
-			// will be unset by the this call.
-			$listingObject->setCheckedList(NULL, $HTTP_VARS);
-					
-			$HTTP_VARS['user_id_rs'] = $listingObject->getCheckedList();
-				
-			// Don't need the Listings object anymore.
-			unset($listingObject);
-		}
-					
-		reset($HTTP_VARS['user_id_rs']);
-		while(list(,$uid) = each($HTTP_VARS['user_id_rs']))
-		{
-			if(in_array(fetch_user_type($uid), get_min_user_type_r($HTTP_SESSION_VARS['user_type'])))
-				$filtered_user_id_rs[] = $uid;
-		}
-		
-		if(strlen($HTTP_VARS['subject'])>0 && (strlen($HTTP_VARS['message'])>0 || $HTTP_VARS['no_message']=='true'))
-		{
-			send_email_to_userids(
-					$filtered_user_id_rs, 
-					$from, 
-					$fromname, 
-					$HTTP_VARS['subject'], 
-					$HTTP_VARS['message']);
-		}
-		else
-		{
-			show_email_form(
-					get_user_ids_tovalue($filtered_user_id_rs), 
-					replace_lang_var('user_desc', $CONFIG_VARS['site.title'], $LANG_VARS['users']), 
-					$from, 
-					$fromname, 
-					$HTTP_VARS['subject'],
-					$HTTP_VARS['message'],
-					$HTTP_VARS);
-		}
-	}
-	else if($HTTP_VARS['op'] == 'send_to_uid' && is_user_valid($HTTP_VARS['uid']) && is_user_allowed_to_borrow(fetch_user_type($HTTP_VARS['uid']), $HTTP_SESSION_VARS['user_type']))
-	{
-		// Only support NON-PHP Email functionality for single UID email.
-		if($CONFIG_VARS['email.use_php_mail']===FALSE)
-		{
-			$touser_r = fetch_user_r($HTTP_VARS['uid']);
-			send_nonphp_email($touser_r['email'], $touser_r['fullname'], $from, $fromname, $HTTP_VARS['subject'], $HTTP_VARS['message']);
-		}
-		else
-		{
+			// If everything is provided, we can send email.
 			if(strlen($HTTP_VARS['subject'])>0 && (strlen($HTTP_VARS['message'])>0 || $HTTP_VARS['no_message']=='true'))
 			{
 				send_email_to_userids(
-						array($HTTP_VARS['uid']), 
-						$from, 
-						$fromname, 
+						get_user_id_rs(), 
+						fetch_user_email($from_user_r['user_id']), 
+						$from_user_r['fullname'],
 						$HTTP_VARS['subject'], 
 						$HTTP_VARS['message']);
 			}
 			else
 			{
 				show_email_form(
-						fetch_user_name($HTTP_VARS['uid'])." (".$HTTP_VARS['uid'].")", 
-						NULL, 
-						$from, 
-						$fromname, 
+						get_user_ids_tovalue(get_user_id_rs()),
+						$HTTP_VARS['toname'],
+						$from_user_r['user_id'],
+						$from_user_r['fullname'],
 						$HTTP_VARS['subject'],
 						$HTTP_VARS['message'],
 						$HTTP_VARS);
 			}
 		}
-	}
-	else if($HTTP_VARS['op'] == 'send_to_site_admin' && $CONFIG_VARS['email.send_to_site_admin']!==FALSE)
-	{
-		// Avoid any attempts to foil required validation checks.
-		$HTTP_VARS['from'] = trim(strip_tags($HTTP_VARS['from']));
-		$HTTP_VARS['fromname'] = trim(strip_tags($HTTP_VARS['fromname']));
-	
-		if($CONFIG_VARS['email.use_php_mail']===FALSE)
+		else if($CONFIG_VARS['email.use_php_mail']!==FALSE && $HTTP_VARS['op'] == 'send_to_usertype' && is_usertype_valid($HTTP_VARS['usertype']) && in_array(ifempty($HTTP_VARS['usertype'],'N'), get_min_user_type_r($HTTP_SESSION_VARS['user_type'])))
 		{
-			send_nonphp_email(
-					$CONFIG_VARS['site.admin_email'], 
-					$CONFIG_VARS['site.admin_name'], 
-					$HTTP_VARS['from'], 
-					$HTTP_VARS['fromname'], 
-					$HTTP_VARS['subject'],
-					$HTTP_VARS['message']);
-		}
-		else
-		{
-			// Only try to email if all the info is there, or we have been to the email form.  In the latter case we
-			// are also getting the opendb_email function to test the from and subject values for us.
-			if((strlen($HTTP_VARS['from'])>0 && strlen($HTTP_VARS['subject'])>0 && strlen($HTTP_VARS['message'])>0) || $HTTP_VARS['no_message'] == 'true')
+			// Default toname for bulk email.
+			if(strlen($HTTP_VARS['toname'])==0)
+				$HTTP_VARS['toname'] = replace_lang_var('user_desc', get_usertype_description($HTTP_VARS['usertype']), $LANG_VARS['users']);
+				
+			if(strlen($HTTP_VARS['subject'])>0 && (strlen($HTTP_VARS['message'])>0 || $HTTP_VARS['no_message']=='true'))
 			{
-				$result = opendb_email(
-						$CONFIG_VARS['site.admin_email'], 
-						$CONFIG_VARS['site.admin_name'],
-						$HTTP_VARS['from'], 
-						$HTTP_VARS['fromname'], 
+				send_email_to_userids(
+						get_user_id_rs(array($HTTP_VARS['usertype'])), 
+						fetch_user_email($from_user_r['user_id']), 
+						$from_user_r['fullname'], 
 						$HTTP_VARS['subject'], 
 						$HTTP_VARS['message']);
+			}
+			else
+			{
+				show_email_form(
+						get_user_ids_tovalue(get_user_id_rs(array($HTTP_VARS['usertype']))),
+						$HTTP_VARS['toname'],
+						$from_user_r['user_id'],
+						$from_user_r['fullname'],
+						$HTTP_VARS['subject'], 
+						$HTTP_VARS['message'],
+						$HTTP_VARS);
+			}
+		}
+		else if($CONFIG_VARS['email.use_php_mail']!==FALSE && $HTTP_VARS['op'] == 'send_to_uids' && (is_not_empty_array($HTTP_VARS['user_id_rs']) || strlen(trim($HTTP_VARS['checked_user_id_rs_list']))>0))
+		{
+			// Remove $user_id's that are above the user type of the current user.
+			$filtered_user_id_rs = NULL;
+			
+			// If seeded from user_listing.php, we need to consolidate the list.
+			if(is_not_empty_array($HTTP_VARS['checked_user_id_rs']) || strlen(trim($HTTP_VARS['checked_user_id_rs_list']))>0)
+			{
+				$listingObject = new HTML_Listing($PHP_SELF, $HTTP_VARS);
+	
+				$listingObject->setCheckBoxColumnAndInitList('user_id_rs');
 				
-				if($result===TRUE)
+				// The checked_user_id_rs and checked_user_id_rs_list variables
+				// will be unset by the this call.
+				$HTTP_VARS = $listingObject->getHttpVars();
+				
+				$HTTP_VARS['user_id_rs'] = $listingObject->getCheckedList();
+					
+				// Don't need the HTML_Listing object anymore.
+				unset($listingObject);
+			}
+						
+			reset($HTTP_VARS['user_id_rs']);
+			while(list(,$uid) = each($HTTP_VARS['user_id_rs']))
+			{
+				if(in_array(fetch_user_type($uid), get_min_user_type_r($HTTP_SESSION_VARS['user_type'])))
 				{
-					echo("<p><div class=\"success\">".$LANG_VARS['message_sent_to']." ".replace_lang_var('site', $CONFIG_VARS['site.title'], $LANG_VARS['site_administrator'])."</div></p>");
+					$filtered_user_id_rs[] = $uid;
+				}
+			}
+			
+			if(strlen($HTTP_VARS['subject'])>0 && (strlen($HTTP_VARS['message'])>0 || $HTTP_VARS['no_message']=='true'))
+			{
+				send_email_to_userids(
+						$filtered_user_id_rs, 
+						fetch_user_email($from_user_r['user_id']), 
+						$from_user_r['fullname'], 
+						$HTTP_VARS['subject'], 
+						$HTTP_VARS['message']);
+			}
+			else
+			{
+				show_email_form(
+						get_user_ids_tovalue($filtered_user_id_rs),
+						replace_lang_var('user_desc', $CONFIG_VARS['site.title'], $LANG_VARS['users']),
+						$from_user_r['user_id'],
+						$from_user_r['fullname'],
+						$HTTP_VARS['subject'],
+						$HTTP_VARS['message'],
+						$HTTP_VARS);
+			}
+		}
+		else if($HTTP_VARS['op'] == 'send_to_uid' && is_user_valid($HTTP_VARS['uid']) && is_user_allowed_to_borrow(fetch_user_type($HTTP_VARS['uid']), $HTTP_SESSION_VARS['user_type']))
+		{
+			// Only support NON-PHP Email functionality for single UID email.
+			if($CONFIG_VARS['email.use_php_mail']===FALSE)
+			{
+				$touser_r = fetch_user_r($HTTP_VARS['uid']);
+				send_nonphp_email(
+						fetch_user_email($touser_r['user_id']), 
+						$touser_r['fullname'], 
+						fetch_user_email($from_user_r['user_id']), 
+						$from_user_r['fullname'],
+						$HTTP_VARS['subject'], 
+						$HTTP_VARS['message']);
+			}
+			else
+			{
+				if(strlen($HTTP_VARS['subject'])>0 && (strlen($HTTP_VARS['message'])>0 || $HTTP_VARS['no_message']=='true'))
+				{
+					send_email_to_userids(
+							array($HTTP_VARS['uid']), 
+							fetch_user_email($from_user_r['user_id']), 
+							$from_user_r['fullname'], 
+							$HTTP_VARS['subject'], 
+							$HTTP_VARS['message']);
 				}
 				else
 				{
-					echo format_error_block($result);
-			
-					// Hide the fact we might have already been into the form.
-					unset($HTTP_VARS['no_message']);
 					show_email_form(
-						NULL, // email 
-						replace_lang_var('site', $CONFIG_VARS['site.title'], $LANG_VARS['site_administrator']),
-						$HTTP_VARS['from'], 
-						$HTTP_VARS['fromname'],
-						$HTTP_VARS['subject'],
-						$HTTP_VARS['message'],
-						$HTTP_VARS);
+							$HTTP_VARS['uid'],
+							fetch_user_name($HTTP_VARS['uid']),
+							$from_user_r['user_id'],
+							$from_user_r['fullname'],
+							$HTTP_VARS['subject'],
+							$HTTP_VARS['message'],
+							$HTTP_VARS);
 				}
 			}
-			else // Else first time into the email form.
+		}
+		else if($HTTP_VARS['op'] == 'send_to_site_admin' && $CONFIG_VARS['email.send_to_site_admin']!==FALSE)
+		{
+			// Avoid any attempts to foil required validation checks.
+			$HTTP_VARS['from'] = trim(strip_tags($HTTP_VARS['from']));
+			$HTTP_VARS['fromname'] = trim(strip_tags($HTTP_VARS['fromname']));
+		
+			if($CONFIG_VARS['email.use_php_mail']===FALSE)
 			{
-				show_email_form(
-						NULL,// email 
-						replace_lang_var('site', $CONFIG_VARS['site.title'], $LANG_VARS['site_administrator']), 
+				send_nonphp_email(
+						$CONFIG_VARS['site.admin_email'], 
+						$CONFIG_VARS['site.admin_name'], 
 						$HTTP_VARS['from'], 
-						$HTTP_VARS['fromname'],
+						$HTTP_VARS['fromname'], 
 						$HTTP_VARS['subject'],
-						$HTTP_VARS['message'],
-						$HTTP_VARS);
+						$HTTP_VARS['message']);
+			}
+			else
+			{
+				// Only try to email if all the info is there, or we have been to the email form.  In the latter case we
+				// are also getting the opendb_email function to test the from and subject values for us.
+				if((strlen($HTTP_VARS['from'])>0 && strlen($HTTP_VARS['subject'])>0 && strlen($HTTP_VARS['message'])>0) || $HTTP_VARS['no_message'] == 'true')
+				{
+					$result = opendb_email(
+							$CONFIG_VARS['site.admin_email'], 
+							$CONFIG_VARS['site.admin_name'],
+							$HTTP_VARS['from'], 
+							$HTTP_VARS['fromname'], 
+							$HTTP_VARS['subject'], 
+							$HTTP_VARS['message']);
+					
+					if($result===TRUE)
+					{
+						echo("<p><div class=\"success\">".$LANG_VARS['message_sent_to']." ".replace_lang_var('site', $CONFIG_VARS['site.title'], $LANG_VARS['site_administrator'])."</div></p>");
+					}
+					else
+					{
+						echo format_error_block($result);
+				
+						// Hide the fact we might have already been into the form.
+						unset($HTTP_VARS['no_message']);
+						show_email_form(
+							NULL, // email 
+							replace_lang_var('site', $CONFIG_VARS['site.title'], $LANG_VARS['site_administrator']),
+							NULL, // from_userid
+							NULL, // from_fullname
+							$HTTP_VARS['subject'],
+							$HTTP_VARS['message'],
+							$HTTP_VARS);
+					}
+				}
+				else // Else first time into the email form.
+				{
+					show_email_form(
+							NULL,// email 
+							replace_lang_var('site', $CONFIG_VARS['site.title'], $LANG_VARS['site_administrator']), 
+							NULL, // from_userid
+							NULL, // from_fullname
+							$HTTP_VARS['subject'],
+							$HTTP_VARS['message'],
+							$HTTP_VARS);
+				}
 			}
 		}
+		else
+		{
+			echo("<div class=\"error\">".$LANG_VARS['operation_not_available']."</div>");
+		}
+		
+		// Always have a redirect link, for after email and also to abort email send.
+		if (strlen($HTTP_VARS['redirect_link'])>0)
+		{
+			echo format_footer_links(array(array(url=>urldecode($HTTP_VARS['redirect_url']),text=>$HTTP_VARS['redirect_link'])));
+		}
+	
+		echo _theme_footer();
 	}
 	else
 	{
-		echo("<div class=\"error\">".$LANG_VARS['operation_not_available']."</div>");
+		// invalid login, so login instead.
+		include("./login.php");
 	}
-	
-	// Always have a redirect link, for after email and also to abort email send.
-	if (strlen($HTTP_VARS['redirect_link'])>0){
-		echo format_footer_links(array(array(url=>urldecode($HTTP_VARS['redirect_url']),text=>$HTTP_VARS['redirect_link'])));
-	}
-
-	echo _theme_footer();
-}
+}//if($CONFIG_VARS['site.enable']!==FALSE)
 else
 {
-	include("./include/invalidsession.php");
+	echo _theme_header($LANG_VARS['site_is_disabled'], FALSE);
+	echo _theme_error($LANG_VARS['site_is_disabled']);
+	echo _theme_footer();
 }
 
 // Cleanup after begin.inc.php
