@@ -1,5 +1,5 @@
 <?php
-/* 	OpenDb - Open Lending Database Project
+/* 	OpenDb - Open Media Lending Database
 	Copyright (C) 2001,2002 by Jason Pell
 
 	This program is free software; you can redistribute it and/or
@@ -22,7 +22,8 @@
 include_once("./functions/user.php");
 include_once("./functions/item.php");
 include_once("./functions/utils.php");
-include_once("./functions/function.php");
+include_once("./functions/database.php");
+include_once("./functions/logging.php");
 include_once("./functions/datetime.php");
 
 /**
@@ -38,8 +39,10 @@ function get_orderby_clause($order_by, $sortorder)
 		return "order by bi.borrower_id $sortorder";
 	else if($order_by === "owner")
 		return "order by ii.owner_id $sortorder";
-	else
-		return "ORDER BY bi.update_on $sortorder";//no order by!	   
+	else if($order_by === "update_on" || strlen($order_by)==0)
+		return "ORDER BY bi.update_on $sortorder";//no order by!
+	else 
+		return "ORDER BY $order_by $sortorder";
 }
 
 //
@@ -65,17 +68,14 @@ function fetch_all_borrowed_item_cnt()
 
 function fetch_all_borrowed_item_rs($order_by, $sortorder, $start_index=NULL, $items_per_page=NULL)
 {
-	// from config.php
-	global $CONFIG_VARS;
-	
-	$query = "SELECT bi.sequence_number, bi.item_id, bi.instance_no, IF(bi.borrow_duration>0,UNIX_TIMESTAMP(DATE_ADD(bi.update_on, INTERVAL bi.borrow_duration DAY)),NULL) as due_date, bi.borrower_id, i.s_item_type, i.title, ii.owner_id, ii.s_status_type ".
+	$query = "SELECT bi.sequence_number, bi.item_id, bi.instance_no, UNIX_TIMESTAMP(DATE_ADD(bi.update_on, INTERVAL bi.borrow_duration DAY)) as due_date, bi.borrower_id, i.s_item_type, i.title, ii.owner_id, ii.s_status_type ".
 				"FROM item i, item_instance ii, borrowed_item bi ".
 				"WHERE i.id = ii.item_id AND ii.instance_no = bi.instance_no AND bi.item_id = ii.item_id AND ".
 				"bi.status = 'B' ".
 				get_orderby_clause($order_by, $sortorder);
 
-	if(is_numeric($start_index))
-		$query .= " LIMIT " .$start_index. ", " .ifempty($items_per_page, $CONFIG_VARS['listings.items_per_page']);
+	if(is_numeric($start_index) && is_numeric($items_per_page))
+		$query .= ' LIMIT ' .$start_index. ', ' .$items_per_page;
 
 	$result = run_opendb_query($query);
 	if($result && mysql_num_rows($result)>0)
@@ -112,17 +112,14 @@ function fetch_my_borrowed_item_cnt($borrower_id)
 */
 function fetch_my_borrowed_item_rs($borrower_id, $order_by, $sortorder, $start_index=NULL, $items_per_page=NULL)
 {
-	// from config.php
-	global $CONFIG_VARS;
-	
-	$query = "SELECT bi.sequence_number, bi.item_id, bi.instance_no, IF(bi.borrow_duration>0,UNIX_TIMESTAMP(DATE_ADD(bi.update_on, INTERVAL bi.borrow_duration DAY)),NULL) as due_date, i.s_item_type, i.title, ii.owner_id, ii.s_status_type ".
+	$query = "SELECT bi.sequence_number, bi.item_id, bi.instance_no, UNIX_TIMESTAMP(DATE_ADD(bi.update_on, INTERVAL bi.borrow_duration DAY)) as due_date, i.s_item_type, i.title, ii.owner_id, ii.s_status_type ".
 				"FROM item i, item_instance ii, borrowed_item bi ".
 				"WHERE i.id = ii.item_id AND ii.instance_no = bi.instance_no AND bi.item_id = ii.item_id AND ".
 				"bi.status = 'B' and bi.borrower_id = '".$borrower_id."' ".
 				get_orderby_clause($order_by, $sortorder);
 
-	if(is_numeric($start_index))
-		$query .= " LIMIT " .$start_index. ", " .ifempty($items_per_page, $CONFIG_VARS['listings.items_per_page']);
+	if(is_numeric($start_index) && is_numeric($items_per_page))
+		$query .= ' LIMIT ' .$start_index. ', ' .$items_per_page;
 
 	$result = run_opendb_query($query);
 	if($result && mysql_num_rows($result)>0)
@@ -153,17 +150,14 @@ function fetch_all_reserved_item_cnt()
 
 function fetch_all_reserved_item_rs($order_by, $sortorder, $start_index=NULL, $items_per_page=NULL)
 {
-	// from config.php
-	global $CONFIG_VARS;
-	
-	$query = "SELECT bi.sequence_number, bi.item_id, bi.instance_no, bi.borrower_id, i.s_item_type, i.title, ii.owner_id, ii.borrow_duration, ii.s_status_type, UNIX_TIMESTAMP(bi.update_on) as update_on ".
+	$query = "SELECT bi.sequence_number, bi.item_id, bi.instance_no, bi.borrower_id, i.s_item_type, i.title, ii.owner_id, ii.borrow_duration, ii.s_status_type, UNIX_TIMESTAMP(bi.update_on) as reserve_date ".
 				"FROM item i, item_instance ii, borrowed_item bi ".
 				"WHERE i.id = ii.item_id AND ii.instance_no = bi.instance_no AND bi.item_id = ii.item_id AND ".
 				"bi.status = 'R' ".
 				get_orderby_clause($order_by, $sortorder);
 
-	if(is_numeric($start_index))
-		$query .= " LIMIT " .$start_index. ", " .ifempty($items_per_page, $CONFIG_VARS['listings.items_per_page']);
+	if(is_numeric($start_index) && is_numeric($items_per_page))
+		$query .= ' LIMIT ' .$start_index. ', ' .$items_per_page;
 
 	$result = run_opendb_query($query);
 	if($result && mysql_num_rows($result)>0)
@@ -198,10 +192,7 @@ function fetch_my_reserved_item_cnt($borrower_id)
 //
 function fetch_my_reserved_item_rs($borrower_id, $order_by=NULL, $sortorder=NULL, $start_index=NULL, $items_per_page=NULL)
 {
-	// from config.php
-	global $CONFIG_VARS;
-	
-	$query = "SELECT bi.sequence_number, bi.item_id, bi.instance_no, i.s_item_type, i.title, ii.owner_id, ii.borrow_duration, ii.s_status_type, UNIX_TIMESTAMP(bi.update_on) as update_on ".
+	$query = "SELECT bi.sequence_number, bi.item_id, bi.instance_no, i.s_item_type, i.title, ii.owner_id, ii.borrow_duration, ii.s_status_type, UNIX_TIMESTAMP(bi.update_on) as reserve_date ".
 				"FROM item i, item_instance ii, borrowed_item bi ".
 				"WHERE i.id = ii.item_id AND ii.instance_no = bi.instance_no AND bi.item_id = ii.item_id AND ".
 				"bi.status = 'R' and bi.borrower_id = '".$borrower_id."' ";
@@ -209,8 +200,8 @@ function fetch_my_reserved_item_rs($borrower_id, $order_by=NULL, $sortorder=NULL
 	if(strlen($order_by)>0)
 		$query .= get_orderby_clause($order_by, $sortorder);
 		
-	if(is_numeric($start_index))
-		$query .= " LIMIT " .$start_index. ", " .ifempty($items_per_page, $CONFIG_VARS['listings.items_per_page']);
+	if(is_numeric($start_index) && is_numeric($items_per_page))
+		$query .= ' LIMIT ' .$start_index. ', ' .$items_per_page;
 
 	$result = run_opendb_query($query);
 	if($result && mysql_num_rows($result)>0)
@@ -237,17 +228,14 @@ function fetch_my_history_item_cnt($borrower_id)
 
 function fetch_my_history_item_rs($borrower_id, $order_by, $sortorder, $start_index=NULL, $items_per_page=NULL)
 {
-	// from config.php
-	global $CONFIG_VARS;
-
-	$query = "SELECT bi.sequence_number, bi.item_id, bi.instance_no, i.s_item_type, i.title, ii.owner_id, UNIX_TIMESTAMP(bi.update_on) as return_date, bi.borrow_duration, bi.total_duration, bi.status, ii.s_status_type ".
+	$query = "SELECT bi.sequence_number, bi.item_id, bi.instance_no, i.s_item_type, i.title, ii.owner_id, UNIX_TIMESTAMP(DATE_SUB(bi.update_on, INTERVAL bi.total_duration DAY)) as borrow_date, UNIX_TIMESTAMP(bi.update_on) as return_date, bi.borrow_duration, bi.total_duration, bi.status, ii.s_status_type ".
 				"FROM item i, item_instance ii, borrowed_item bi ".
 				"WHERE i.id = ii.item_id AND bi.instance_no = ii.instance_no AND bi.item_id = ii.item_id AND ".
 				" bi.status IN('C','X') AND bi.borrower_id = '".$borrower_id."' ".
 				get_orderby_clause($order_by, $sortorder);
 
-	if(is_numeric($start_index))
-		$query .= " LIMIT " .$start_index. ", " .ifempty($items_per_page, $CONFIG_VARS['listings.items_per_page']);
+	if(is_numeric($start_index) && is_numeric($items_per_page))
+		$query .= ' LIMIT ' .$start_index. ', ' .$items_per_page;
 
 	$result = run_opendb_query($query);
 	if($result && mysql_num_rows($result)>0)
@@ -299,18 +287,15 @@ function fetch_item_instance_history_cnt($item_id, $instance_no)
 
 function fetch_item_instance_history_rs($item_id, $instance_no, $order_by, $sortorder, $start_index=NULL, $items_per_page=NULL)
 {
-	// from config.php
-	global $CONFIG_VARS;
-
 	// Note that 'return_date' will only be used where status='C' anyway!!!
-	$query = "SELECT bi.sequence_number, bi.borrower_id, UNIX_TIMESTAMP(bi.update_on) as return_date, IF(bi.borrow_duration>0,UNIX_TIMESTAMP(DATE_ADD(bi.update_on, INTERVAL bi.borrow_duration DAY)),NULL) as due_date, bi.borrow_duration, bi.total_duration, TO_DAYS(now()) - TO_DAYS(bi.update_on) as calc_total_duration, bi.status, ii.borrow_duration as ii_borrow_duration, ii.s_status_type, i.s_item_type ".
+	$query = "SELECT bi.sequence_number, bi.borrower_id, UNIX_TIMESTAMP(DATE_SUB(bi.update_on, INTERVAL bi.total_duration DAY)) as borrow_date, UNIX_TIMESTAMP(bi.update_on) as return_date, UNIX_TIMESTAMP(DATE_ADD(bi.update_on, INTERVAL bi.borrow_duration DAY)) as due_date, bi.borrow_duration, bi.total_duration, TO_DAYS(now()) - TO_DAYS(bi.update_on) as calc_total_duration, bi.status, ii.borrow_duration as ii_borrow_duration, ii.s_status_type, i.s_item_type ".
 				"FROM item_instance ii, item i, borrowed_item bi ".
 				"WHERE  i.id = ii.item_id AND ii.instance_no = bi.instance_no AND bi.item_id = ii.item_id AND ".
 				" bi.item_id = '".$item_id."' AND bi.instance_no = '".$instance_no."' ".
 				get_orderby_clause($order_by, $sortorder);
 
-	if(is_numeric($start_index))
-		$query .= " LIMIT " .$start_index. ", " .ifempty($items_per_page, $CONFIG_VARS['listings.items_per_page']);
+	if(is_numeric($start_index) && is_numeric($items_per_page))
+		$query .= ' LIMIT ' .$start_index. ', ' .$items_per_page;
 
 	$result = run_opendb_query($query);
 	if($result && mysql_num_rows($result)>0)
@@ -347,10 +332,7 @@ function fetch_owner_reserved_item_cnt($owner_id)
 //
 function fetch_owner_reserved_item_rs($owner_id, $order_by=NULL, $sortorder=NULL, $start_index=NULL, $items_per_page=NULL)
 {
-	// from config.php
-	global $CONFIG_VARS;
-
-	$query = "SELECT bi.sequence_number, bi.item_id, bi.instance_no, i.s_item_type, i.title, ii.borrow_duration, ii.s_status_type, bi.borrower_id, UNIX_TIMESTAMP(bi.update_on) as update_on ".
+	$query = "SELECT bi.sequence_number, bi.item_id, bi.instance_no, i.s_item_type, i.title, ii.borrow_duration, ii.s_status_type, bi.borrower_id, UNIX_TIMESTAMP(bi.update_on) as reserve_date ".
 				"FROM item i, item_instance ii, borrowed_item bi ".
 				"WHERE i.id = ii.item_id AND ii.instance_no = bi.instance_no AND bi.item_id = ii.item_id AND ".
 				"ii.owner_id = '".$owner_id."' AND ".
@@ -359,8 +341,8 @@ function fetch_owner_reserved_item_rs($owner_id, $order_by=NULL, $sortorder=NULL
 	if(strlen($order_by)>0)
 		$query .= get_orderby_clause($order_by, $sortorder);
 
-	if(is_numeric($start_index))
-		$query .= " LIMIT " .$start_index. ", " .ifempty($items_per_page, $CONFIG_VARS['listings.items_per_page']);
+	if(is_numeric($start_index) && is_numeric($items_per_page))
+		$query .= ' LIMIT ' .$start_index. ', ' .$items_per_page;
 	
 	$result = run_opendb_query($query);
 	if($result && mysql_num_rows($result)>0)
@@ -395,18 +377,15 @@ function fetch_owner_borrowed_item_cnt($owner_id)
 //
 function fetch_owner_borrowed_item_rs($owner_id, $order_by, $sortorder, $start_index=NULL, $items_per_page=NULL)
 {
-	// from config.php
-	global $CONFIG_VARS;
-	
-	$query = "SELECT bi.sequence_number, bi.item_id, bi.instance_no, IF(bi.borrow_duration>0,UNIX_TIMESTAMP(DATE_ADD(bi.update_on, INTERVAL bi.borrow_duration DAY)),NULL) as due_date, i.s_item_type, i.title, ii.s_status_type, bi.borrower_id  ".
+	$query = "SELECT bi.sequence_number, bi.item_id, bi.instance_no, UNIX_TIMESTAMP(DATE_ADD(bi.update_on, INTERVAL bi.borrow_duration DAY)) as due_date, i.s_item_type, i.title, ii.s_status_type, bi.borrower_id  ".
 				"FROM item i, item_instance ii, borrowed_item bi ".
 				"WHERE i.id = ii.item_id AND ii.instance_no = bi.instance_no AND bi.item_id = ii.item_id and ".
 				"ii.owner_id = '".$owner_id."' and ".
 				"bi.status = 'B' ".
 				get_orderby_clause($order_by, $sortorder);
 
-	if(is_numeric($start_index))
-		$query .= " LIMIT " .$start_index. ", " .ifempty($items_per_page, $CONFIG_VARS['listings.items_per_page']);
+	if(is_numeric($start_index) && is_numeric($items_per_page))
+		$query .= ' LIMIT ' .$start_index. ', ' .$items_per_page;
 		
 	$result = run_opendb_query($query);
 	if($result && mysql_num_rows($result)>0)
@@ -415,6 +394,32 @@ function fetch_owner_borrowed_item_rs($owner_id, $order_by, $sortorder, $start_i
 		return FALSE;
 }
 
+/**
+* Fetch a list of all items due for renewal within specified daysleft limit.
+* 
+* Duration range
+*	+1 = once one day overdue
+*	0 = on day due
+*	-1 = one day before due
+*/
+function fetch_reminder_borrowed_item_rs($duration_range)
+{
+	$query = "SELECT bi.sequence_number, bi.item_id, bi.instance_no, i.s_item_type, i.title, ii.s_status_type, bi.borrower_id, UNIX_TIMESTAMP(DATE_ADD(bi.update_on, INTERVAL bi.borrow_duration DAY)) as due_date, bi.borrow_duration, (TO_DAYS(now()) - TO_DAYS(bi.update_on)) as total_duration ".
+			"FROM item i, item_instance ii, borrowed_item bi ".
+			"WHERE i.id = ii.item_id AND ".
+			"ii.instance_no = bi.instance_no AND ".
+			"bi.item_id = ii.item_id AND ".
+			"bi.status = 'B' AND ".
+			"bi.borrow_duration > 0 AND ".
+			"((TO_DAYS(NOW()) - TO_DAYS(DATE_ADD(bi.update_on, INTERVAL bi.borrow_duration DAY))) >= $duration_range)";
+	
+	$result = run_opendb_query($query);
+	if($result && mysql_num_rows($result)>0)
+		return $result;
+	else
+		return FALSE;
+}
+
 /**
 	This will return a count of all borrowed_items of the $status which
 	have been updated on or before the $update_on timestamp.  The update_on
@@ -515,7 +520,7 @@ function is_item_reserved_or_borrowed($item_id, $instance_no)
 	// or borrowed the item.
 	$query = "SELECT 'X' FROM borrowed_item " .
 			"WHERE item_id = '$item_id' AND instance_no = '$instance_no' AND " .
-			"(status = 'R' or status = 'B')";
+			"status IN('R', 'B') ";
 
 	$result = run_opendb_query($query);
 	if ($result && mysql_num_rows($result)>0)
@@ -729,7 +734,7 @@ function is_item_reserved_or_borrowed_by_user($item_id, $instance_no, $borrower_
 	$query = "SELECT 'X' FROM borrowed_item " .
 			"WHERE item_id = '$item_id' AND instance_no = '$instance_no' AND ".
 			"borrower_id = '".$borrower_id."' AND ".
-			"(status = 'R' OR status = 'B')";
+			"status IN ('R', 'B')";
 
 	$result = run_opendb_query($query);
 	if ($result && mysql_num_rows($result)>0)
@@ -775,7 +780,7 @@ function is_item_borrowed_or_returned_by_user($item_id, $instance_no, $borrower_
 	$query = "SELECT 'X' FROM borrowed_item " .
 			"WHERE item_id = '$item_id' AND instance_no = '$instance_no' AND ".
 			"borrower_id = '".$borrower_id."' AND ".
-			"(status = 'B' OR status = 'C')";
+			"status IN ('B', 'C')";
 
 	$result = run_opendb_query($query);
 	if ($result && mysql_num_rows($result)>0)
@@ -1036,7 +1041,7 @@ function delete_item_instance_inactive_borrowed_items($item_id, $instance_no)
 	
 	$query= "DELETE FROM borrowed_item WHERE item_id = $item_id AND instance_no = $instance_no AND status IN ('X','C')";
 	$delete = run_opendb_query($query);
-	if ($delete)
+	if($delete)
 	{
 		opendb_log("Deleted borrowed items (item_id=$item_id, instance_no=$instance_no, update_who=".$HTTP_SESSION_VARS['user_id'].")");
 		return TRUE;
@@ -1047,4 +1052,22 @@ function delete_item_instance_inactive_borrowed_items($item_id, $instance_no)
 		return FALSE;
 	}
 }
+
+function delete_item_instance_borrower_borrowed_items($item_id, $instance_no, $borrower_id)
+{
+	global $HTTP_SESSION_VARS;
+	
+	$query= "DELETE FROM borrowed_item WHERE item_id = $item_id AND instance_no = $instance_no AND borrower_id = '$borrower_id'";
+	$delete = run_opendb_query($query);
+	if($delete)
+	{
+		opendb_log("Deleted borrower borrowed items (item_id=$item_id, instance_no=$instance_no, borrower_id=$borrower_id, update_who=".$HTTP_SESSION_VARS['user_id'].")");
+		return TRUE;
+	}
+	else
+	{
+		opendb_log("Failed to delete borrower borrowed items (item_id=$item_id, instance_no=$instance_no, borrower_id=$borrower_id, update_who=".$HTTP_SESSION_VARS['user_id'].") [".mysql_error()."]");
+		return FALSE;
+	}
+}
 ?>
